@@ -55,6 +55,7 @@ struct newtColors newtDefaultColorPalette = {
 	"blue",					/* scale full */
 	"red",					/* scale empty */
 	"blue", "lightgray",			/* disabled entry fg, bg */
+	"white", "blue",			/* compact button fg, bg */
 };
 
 static struct keymap keymap[] = {
@@ -104,7 +105,7 @@ static char keyPrefix = '\033';
 static char * version = "Newt windowing library version " VERSION
 			" - (C) 1996 Red Hat Software. "
 		        "Redistributable under the term of the Library "
-		        "GNU Public Library. "
+		        "GNU Public License. "
 			"Written by Erik Troan\n";
 
 static newtSuspendCallback suspendCallback = NULL;
@@ -113,6 +114,12 @@ void newtSetSuspendCallback(newtSuspendCallback cb) {
     suspendCallback = cb;
 }
 
+void newtFlushInput(void) {
+    while (SLang_input_pending(0)) {
+	SLang_getkey();
+    }
+}
+
 void newtRefresh(void) {
     SLsmg_refresh();
 }
@@ -211,6 +218,9 @@ void newtSetColors(struct newtColors colors) {
 			colors.fullScale);
     SLtt_set_color(NEWT_COLORSET_DISENTRY, "", colors.disabledEntryFg,
 			colors.disabledEntryBg);
+
+    SLtt_set_color(NEWT_COLORSET_COMPACTBUTTON, "", colors.compactButtonFg,
+			colors.compactButtonBg);
 }
 
 int newtGetKey(void) {
@@ -296,6 +306,8 @@ int newtOpenWindow(int left, int top, int width, int height,
     int i, j, row, col;
     int n;
 
+    newtFlushInput();
+
     if (!currentWindow) {
 	currentWindow = windowStack;
     } else {
@@ -454,7 +466,7 @@ void newtDelay(int usecs) {
     select(0, &set, &set, &set, &tv);
 }
 
-struct eventResult newtDefaultEventHandler(struct newtComponent * c, 
+struct eventResult newtDefaultEventHandler(newtComponent c,
 					   struct event ev) {
     struct eventResult er;
 
