@@ -1,6 +1,10 @@
 #ifndef H_NEWT
 #define H_NEWT
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 #define NEWT_COLORSET_ROOT 		2
 #define NEWT_COLORSET_BORDER 		3
 #define NEWT_COLORSET_WINDOW		4
@@ -21,8 +25,7 @@
 #define NEWT_COLORSET_EMPTYSCALE	19
 #define NEWT_COLORSET_FULLSCALE		20
 #define NEWT_COLORSET_DISENTRY		21
-
-enum newtFlagsSense { NEWT_FLAGS_SET, NEWT_FLAGS_RESET };
+#define NEWT_COLORSET_COMPACTBUTTON	22
 
 struct newtColors {
     char * rootFg, * rootBg;
@@ -44,9 +47,26 @@ struct newtColors {
     char * rootTextFg, * rootTextBg;
     char * emptyScale, * fullScale;
     char * disabledEntryFg, * disabledEntryBg;
+    char * compactButtonFg, * compactButtonBg;
 };
 
-typedef struct newtComponent * newtComponent;
+enum newtFlagsSense { NEWT_FLAGS_SET, NEWT_FLAGS_RESET };
+
+#define NEWT_FLAG_RETURNEXIT 	(1 << 0)
+#define NEWT_FLAG_HIDDEN 	(1 << 1)
+#define NEWT_FLAG_SCROLL 	(1 << 2)
+#define NEWT_FLAG_DISABLED 	(1 << 3)
+#define NEWT_FLAG_NOSCROLL 	(1 << 4)	/* for listboxes */
+#define NEWT_FLAG_DOBORDER	(1 << 5)
+
+/* Backwards compatibility */
+#define NEWT_LISTBOX_RETURNEXIT NEWT_FLAG_RETURNEXIT
+#define NEWT_ENTRY_SCROLL	NEWT_FLAG_SCROLL
+#define NEWT_ENTRY_HIDDEN	NEWT_FLAG_HIDDEN
+#define NEWT_ENTRY_RETURNEXIT	NEWT_FLAG_RETURNEXIT
+#define NEWT_ENTRY_DISABLED	NEWT_FLAG_DISABLED
+
+typedef struct newtComponent_struct * newtComponent;
 
 extern struct newtColors newtDefaultColorPalette;
 
@@ -75,6 +95,7 @@ void newtDrawRootText(int row, int col, char * text);
 
 /* Components */
 
+newtComponent newtCompactButton(int left, int top, char * text);
 newtComponent newtButton(int left, int top, char * text);
 newtComponent newtCheckbox(int left, int top, char * text, char defValue,
 			   char * seq, char * result);
@@ -82,7 +103,7 @@ newtComponent newtRadiobutton(int left, int top, char * text, int isDefault,
 			      newtComponent prevButton);
 newtComponent newtRadioGetCurrent(newtComponent setMember);
 newtComponent newtListitem(int left, int top, char * text, int isDefault,
-			      newtComponent prevItem, void * data);
+			      newtComponent prevItem, void * data, int flags);
 void newtListitemSet(newtComponent co, char * text);
 void * newtListitemGetData(newtComponent co);
 
@@ -92,19 +113,25 @@ newtComponent newtVerticalScrollbar(int left, int top, int height,
 				    int normalColorset, int thumbColorset);
 void newtScrollbarSet(newtComponent co, int where, int total);
 
-#define NEWT_LISTBOX_RETURNEXIT (1 << 0)
 newtComponent newtListbox(int left, int top, int height, int flags);
-/* return the data passed to AddEntry */
 void * newtListboxGetCurrent(newtComponent co);
 void newtListboxSetCurrent(newtComponent co, int num);
-void newtListboxAddEntry(newtComponent co, char * text, void * data);
+void newtListboxSetText(newtComponent co, int num, char * text);
 void newtListboxSetEntry(newtComponent co, int num, char * text);
+/* return the data passed to AddEntry */
+void newtListboxSetData(newtComponent co, int num, void * data);
+int newtListboxAddEntry(newtComponent co, char * text, void * data);
+int newtListboxInsertEntry(newtComponent co, char * text, void * data, int num);
+int newtListboxDeleteEntry(newtComponent co, int num);
+void newtListboxGetEntry(newtComponent co, int num, char **text, void **data);
 
 #define NEWT_TEXTBOX_WRAP	(1 << 0)
 #define NEWT_TEXTBOX_SCROLL	(1 << 1)
 
 newtComponent newtTextbox(int left, int top, int with, int height, int flags);
 void newtTextboxSetText(newtComponent co, const char * text);
+void newtTextboxSetHeight(newtComponent co, int height);
+int newtTextboxGetNumLines(newtComponent co);
 
 #define NEWT_FORM_NOF12		(1 << 0)
 
@@ -129,11 +156,6 @@ void newtFormRun(newtComponent co, struct newtExitStruct * es);
 void newtDrawForm(newtComponent form);
 void newtFormAddHotKey(newtComponent co, int key);
 
-#define NEWT_ENTRY_SCROLL	(1 << 0)
-#define NEWT_ENTRY_HIDDEN	(1 << 1)
-#define NEWT_ENTRY_RETURNEXIT	(1 << 2)
-#define NEWT_ENTRY_DISABLED     (1 << 3)
-
 newtComponent newtEntry(int left, int top, char * initialValue, int width,
 			char ** resultPtr, int flags);
 void newtEntrySet(newtComponent co, char * value, int cursorAtEnd);
@@ -181,4 +203,8 @@ void newtFormDestroy(newtComponent form);
 #define NEWT_KEY_F11			NEWT_KEY_EXTRA_BASE + 111
 #define NEWT_KEY_F12			NEWT_KEY_EXTRA_BASE + 112
 
+#ifdef __cplusplus
+} /* End of extern "C" { */
+#endif
+
 #endif /* H_NEWT */
