@@ -18,7 +18,7 @@ struct textbox {
 static void addLine(newtComponent co, const char * s, int len);
 static void textboxDraw(newtComponent co);
 static void addShortLine(newtComponent co, const char * s, int len);
-static struct eventResult textboxEvent(struct newtComponent * c, 
+static struct eventResult textboxEvent(newtComponent c,
 				      struct event ev);
 static void textboxDestroy(newtComponent co);
 
@@ -28,6 +28,16 @@ static struct componentOps textboxOps = {
     textboxDestroy,
 } ;
 
+void newtTextboxSetHeight(newtComponent co, int height) {
+    co->height = height;
+}
+
+int newtTextboxGetNumLines(newtComponent co) {
+    struct textbox * tb = co->data;
+
+    return (tb->numLines);
+}
+
 newtComponent newtTextbox(int left, int top, int width, int height, int flags) {
     newtComponent co;
     struct textbox * tb;
@@ -151,7 +161,7 @@ static void textboxDraw(newtComponent c) {
     }
 }
 
-static struct eventResult textboxEvent(struct newtComponent * co, 
+static struct eventResult textboxEvent(newtComponent co, 
 				      struct event ev) {
     struct textbox * tb = co->data;
     struct eventResult er;
